# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epl/protobuf/v1/stac.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from epl.protobuf.v1 import geometry_pb2 as epl_dot_protobuf_dot_v1_dot_geometry__pb2
from epl.protobuf.v1 import query_pb2 as epl_dot_protobuf_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='epl/protobuf/v1/stac.proto',
  package='epl.protobuf.v1',
  syntax='proto3',
  serialized_options=b'\n\023com.epl.protobuf.v1B\tStacProtoP\001Z.github.com/geo-grpc/api/golang/epl/protobuf/v1\242\002\004STPB',
  serialized_pb=b'\n\x1a\x65pl/protobuf/v1/stac.proto\x12\x0f\x65pl.protobuf.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x19google/protobuf/any.proto\x1a\x1e\x65pl/protobuf/v1/geometry.proto\x1a\x1b\x65pl/protobuf/v1/query.proto\"\xe1\x02\n\nCollection\x12\x14\n\x0cstac_version\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08keywords\x18\x06 \x03(\t\x12\x0f\n\x07license\x18\x07 \x01(\t\x12,\n\tproviders\x18\x08 \x03(\x0b\x32\x19.epl.protobuf.v1.Provider\x12\'\n\x06\x65xtent\x18\t \x01(\x0b\x32\x17.epl.protobuf.v1.Extent\x12=\n\tsummaries\x18\n \x03(\x0b\x32*.epl.protobuf.v1.Collection.SummariesEntry\x1aH\n\x0eSummariesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.epl.protobuf.v1.Stats:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x0b\x10\x0c\"\x8e\x01\n\x11\x43ollectionRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x04\x62\x62ox\x18\x02 \x01(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeDataH\x00\x12\x33\n\nintersects\x18\x03 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryDataH\x00\x42\t\n\x07spatial\"\x07\n\x05Stats\"e\n\x06\x45xtent\x12.\n\x07spatial\x18\x01 \x03(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeData\x12+\n\x08temporal\x18\x02 \x03(\x0b\x32\x19.epl.protobuf.v1.Interval\"^\n\x08Interval\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"I\n\x08Provider\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05roles\x18\x03 \x03(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\xcf\n\n\x08StacItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12(\n\nproperties\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x35\n\x06\x61ssets\x18\x05 \x03(\x0b\x32%.epl.protobuf.v1.StacItem.AssetsEntry\x12/\n\x08geometry\x18\x06 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryData\x12+\n\x04\x62\x62ox\x18\x07 \x01(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeData\x12.\n\x08\x64\x61tetime\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x34\n\x0estart_datetime\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12.\n\x08observed\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x12\x37\n\x11start_observation\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x12\x30\n\x0c\x65nd_datetime\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65nd_observation\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x63reated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x04proj\x18\x10 \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x30\n\rplatform_enum\x18\x11 \x01(\x0e\x32\x19.epl.protobuf.v1.Platform\x12\x10\n\x08platform\x18\x12 \x01(\t\x12\x34\n\x0finstrument_enum\x18\x13 \x01(\x0e\x32\x1b.epl.protobuf.v1.Instrument\x12\x12\n\ninstrument\x18\x14 \x01(\t\x12:\n\x12\x63onstellation_enum\x18\x15 \x01(\x0e\x32\x1e.epl.protobuf.v1.Constellation\x12\x15\n\rconstellation\x18\x16 \x01(\t\x12.\n\x0cmission_enum\x18\x17 \x01(\x0e\x32\x18.epl.protobuf.v1.Mission\x12\x0f\n\x07mission\x18\x18 \x01(\t\x12(\n\x03gsd\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x14\n\x0cstac_version\x18\x1a \x01(\t\x12\x17\n\x0fstac_pb_version\x18\x1b \x01(\t\x12\x17\n\x0fstac_extensions\x18\x1c \x03(\t\x12\x1f\n\x02\x65o\x18\x1d \x01(\x0b\x32\x13.epl.protobuf.v1.Eo\x12#\n\x04view\x18\" \x01(\x0b\x32\x15.epl.protobuf.v1.View\x12)\n\x07landsat\x18\x1f \x01(\x0b\x32\x18.epl.protobuf.v1.Landsat\x12\'\n\x06mosaic\x18  \x01(\x0b\x32\x17.epl.protobuf.v1.Mosaic\x1a\x45\n\x0b\x41ssetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.epl.protobuf.v1.Asset:\x02\x38\x01\x42\x15\n\x13temporal_deprecatedB\n\n\x08temporal\"\xc0\x08\n\x0bStacRequest\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\x0c\n\x02id\x18\x03 \x01(\tH\x00\x12\x33\n\nid_complex\x18\x04 \x01(\x0b\x32\x1d.epl.protobuf.v1.StringFilterH\x00\x12\x12\n\ncollection\x18\x05 \x01(\t\x12(\n\nproperties\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x33\n\nintersects\x18\x07 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryDataH\x01\x12-\n\x04\x62\x62ox\x18\x08 \x01(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeDataH\x01\x12<\n\x10geometry_request\x18\t \x01(\x0b\x32 .epl.protobuf.v1.GeometryRequestH\x01\x12\x34\n\x08\x64\x61tetime\x18\n \x01(\x0b\x32 .epl.protobuf.v1.TimestampFilterH\x02\x12\x34\n\x08observed\x18\x0b \x01(\x0b\x32 .epl.protobuf.v1.TimestampFilterH\x02\x12\x31\n\x07\x63reated\x18\x0c \x01(\x0b\x32 .epl.protobuf.v1.TimestampFilter\x12\x31\n\x07updated\x18\r \x01(\x0b\x32 .epl.protobuf.v1.TimestampFilter\x12-\n\x04proj\x18\x0e \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x30\n\rplatform_enum\x18\x0f \x01(\x0e\x32\x19.epl.protobuf.v1.Platform\x12\x34\n\x0finstrument_enum\x18\x11 \x01(\x0e\x32\x1b.epl.protobuf.v1.Instrument\x12:\n\x12\x63onstellation_enum\x18\x13 \x01(\x0e\x32\x1e.epl.protobuf.v1.Constellation\x12.\n\x0cmission_enum\x18\x15 \x01(\x0e\x32\x18.epl.protobuf.v1.Mission\x12)\n\x03gsd\x18\x17 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\x12&\n\x02\x65o\x18\x18 \x01(\x0b\x32\x1a.epl.protobuf.v1.EoRequest\x12*\n\x04view\x18\x19 \x01(\x0b\x32\x1c.epl.protobuf.v1.ViewRequest\x12\x30\n\x07landsat\x18\x1a \x01(\x0b\x32\x1f.epl.protobuf.v1.LandsatRequest\x12.\n\x06mosaic\x18\x1b \x01(\x0b\x32\x1e.epl.protobuf.v1.MosaicRequestB\n\n\x08identityB\t\n\x07spatialB\n\n\x08temporalJ\x04\x08\x10\x10\x11J\x04\x08\x12\x10\x13J\x04\x08\x14\x10\x15J\x04\x08\x16\x10\x17\"\x80\x02\n\x04View\x12.\n\toff_nadir\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x34\n\x0fincidence_angle\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12,\n\x07\x61zimuth\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bsun_azimuth\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\rsun_elevation\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\x8c\x02\n\x0bViewRequest\x12/\n\toff_nadir\x18\x01 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\x12\x35\n\x0fincidence_angle\x18\x02 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\x12-\n\x07\x61zimuth\x18\x03 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\x12\x31\n\x0bsun_azimuth\x18\x04 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\x12\x33\n\rsun_elevation\x18\x05 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\"\xdb\x01\n\x03Sat\x12\x34\n\x0erelative_orbit\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0borbit_state\x18\x01 \x01(\x0e\x32\x1f.epl.protobuf.v1.Sat.OrbitState\"h\n\nOrbitState\x12\x16\n\x12UKNOWN_ORBIT_STATE\x10\x00\x12\x13\n\x0f\x41SCENDING_ORBIT\x10\x01\x12\x14\n\x10\x44\x45SCENDING_ORBIT\x10\x02\x12\x17\n\x13GEOSTATIONARY_ORBIT\x10\x03\"Z\n\nSatRequest\x12\x16\n\x0erelative_orbit\x18\x06 \x01(\r\x12\x34\n\x0borbit_state\x18\x01 \x01(\x0e\x32\x1f.epl.protobuf.v1.Sat.OrbitState\"\x97\x02\n\x02\x45o\x12\x30\n\x0b\x63loud_cover\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x05\x62\x61nds\x18\x02 \x01(\x0e\x32\x18.epl.protobuf.v1.Eo.Band\"\xb5\x01\n\x04\x42\x61nd\x12\x10\n\x0cUNKNOWN_BAND\x10\x00\x12\x0b\n\x07\x43OASTAL\x10\x02\x12\x08\n\x04\x42LUE\x10\x04\x12\t\n\x05GREEN\x10\x08\x12\x07\n\x03RED\x10\x10\x12\x07\n\x03RGB\x10\x1c\x12\x07\n\x03NIR\x10 \x12\t\n\x05NIR_2\x10!\x12\t\n\x05RGBIR\x10<\x12\n\n\x06SWIR_1\x10@\x12\x0b\n\x06SWIR_2\x10\x80\x01\x12\x08\n\x03PAN\x10\x80\x02\x12\x0b\n\x06\x43IRRUS\x10\x80\x04\x12\x0b\n\x06LWIR_1\x10\x80\x08\x12\x0b\n\x06LWIR_2\x10\x80\x10\"g\n\tEoRequest\x12\x31\n\x0b\x63loud_cover\x18\x01 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\x12\'\n\x05\x62\x61nds\x18\x02 \x01(\x0e\x32\x18.epl.protobuf.v1.Eo.Band\"\xa3\x02\n\x05\x41sset\x12\x0c\n\x04href\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12*\n\x08\x65o_bands\x18\x03 \x01(\x0e\x32\x18.epl.protobuf.v1.Eo.Band\x12.\n\nasset_type\x18\x04 \x01(\x0e\x32\x1a.epl.protobuf.v1.AssetType\x12\x36\n\x0e\x63loud_platform\x18\x05 \x01(\x0e\x32\x1e.epl.protobuf.v1.CloudPlatform\x12\x16\n\x0e\x62ucket_manager\x18\x06 \x01(\t\x12\x15\n\rbucket_region\x18\x07 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x08 \x01(\t\x12\x13\n\x0bobject_path\x18\t \x01(\t\x12\x16\n\x0erequester_pays\x18\n \x01(\x08\"c\n\rDatetimeRange\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"U\n\x0eStacDbResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\"\x9c\x01\n\x03Sar\x12/\n\x08platform\x18\x01 \x01(\x0e\x32\x1d.epl.protobuf.v1.Sar.Platform\">\n\x08Platform\x12\x14\n\x10UNKNOWN_PLATFORM\x10\x00\x12\x0b\n\x07\x45NVISAT\x10\x01\x12\x0f\n\x0bSENTINEL_1A\x10\x02\"$\n\nInstrument\x12\x16\n\x12UNKNOWN_INSTRUMENT\x10\x00\"\xf0\x03\n\x07Landsat\x12\x10\n\x08scene_id\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x42\n\x10processing_level\x18\x03 \x01(\x0e\x32(.epl.protobuf.v1.Landsat.ProcessingLevel\x12\x10\n\x08wrs_path\x18\x04 \x01(\x05\x12\x0f\n\x07wrs_row\x18\x05 \x01(\x05\x12\x35\n\x10\x63loud_cover_land\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\x08wrs_type\x18\x07 \x01(\x0e\x32 .epl.protobuf.v1.Landsat.WRSType\"]\n\x12\x43ollectionCategory\x12\x1f\n\x1bUNKNOWN_COLLECTION_CATEGORY\x10\x00\x12\x06\n\x02\x41\x31\x10\x01\x12\x06\n\x02\x41\x32\x10\x02\x12\x06\n\x02T1\x10\x03\x12\x06\n\x02T2\x10\x04\x12\x06\n\x02RT\x10\x05\"-\n\x07WRSType\x12\x0e\n\nUKNOWN_WRS\x10\x00\x12\x08\n\x04WRS1\x10\x01\x12\x08\n\x04WRS2\x10\x02\"_\n\x0fProcessingLevel\x12\x1c\n\x18UNKNOWN_PROCESSING_LEVEL\x10\x00\x12\x07\n\x03L1G\x10\x01\x12\x08\n\x04L1TP\x10\x02\x12\x07\n\x03L1T\x10\x03\x12\x08\n\x04L1GT\x10\x04\x12\x08\n\x04L1GS\x10\x05\"\xd5\x01\n\x0eLandsatRequest\x12\x10\n\x08scene_id\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x42\n\x10processing_level\x18\x03 \x01(\x0e\x32(.epl.protobuf.v1.Landsat.ProcessingLevel\x12\x10\n\x08wrs_path\x18\x04 \x01(\x05\x12\x0f\n\x07wrs_row\x18\x05 \x01(\x05\x12\x36\n\x10\x63loud_cover_land\x18\x06 \x01(\x0b\x32\x1c.epl.protobuf.v1.FloatFilter\"\x8a\x01\n\x06Mosaic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08quad_key\x18\x02 \x01(\t\x12\r\n\x05zooms\x18\x03 \x03(\x05\x12\x39\n\x11observation_range\x18\x04 \x01(\x0b\x32\x1e.epl.protobuf.v1.DatetimeRange\x12\x16\n\x0eprovenance_ids\x18\x05 \x03(\t\"/\n\rMosaicRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08quad_key\x18\x02 \x01(\t*\xea\x01\n\tAssetType\x12\x11\n\rUNKNOWN_ASSET\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x0b\n\x07GEOTIFF\x10\x02\x12\x08\n\x04LERC\x10\x03\x12\x07\n\x03MRF\x10\x04\x12\x0b\n\x07MRF_IDX\x10\x05\x12\x0b\n\x07MRF_XML\x10\x06\x12\x0e\n\nCO_GEOTIFF\x10\x07\x12\x07\n\x03RAW\x10\x08\x12\r\n\tTHUMBNAIL\x10\t\x12\x08\n\x04TIFF\x10\n\x12\r\n\tJPEG_2000\x10\x0b\x12\x07\n\x03XML\x10\x0c\x12\x07\n\x03TXT\x10\r\x12\x07\n\x03PNG\x10\x0e\x12\x0c\n\x08OVERVIEW\x10\x0f\x12\x08\n\x04JSON\x10\x10\x12\x08\n\x04HTML\x10\x11\x12\x08\n\x04WEBP\x10\x12*Q\n\rCloudPlatform\x12\x1a\n\x16UNKNOWN_CLOUD_PLATFORM\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02\x12\t\n\x05\x41ZURE\x10\x03\x12\x07\n\x03IBM\x10\x04*\xb9\x01\n\x08Platform\x12\x14\n\x10UNKNOWN_PLATFORM\x10\x00\x12\r\n\tLANDSAT_1\x10\x02\x12\r\n\tLANDSAT_2\x10\x04\x12\r\n\tLANDSAT_3\x10\x08\x12\x0f\n\x0bLANDSAT_123\x10\x0e\x12\r\n\tLANDSAT_4\x10\x10\x12\r\n\tLANDSAT_5\x10 \x12\x0e\n\nLANDSAT_45\x10\x30\x12\r\n\tLANDSAT_7\x10@\x12\x0e\n\tLANDSAT_8\x10\x80\x01\x12\x0c\n\x07SWIFT_2\x10\x80\x02*v\n\nInstrument\x12\x16\n\x12UNKNOWN_INSTRUMENT\x10\x00\x12\x07\n\x03OLI\x10\x02\x12\x08\n\x04TIRS\x10\x04\x12\x0c\n\x08OLI_TIRS\x10\x06\x12\t\n\x05POM_1\x10\x08\x12\x06\n\x02TM\x10\x10\x12\x07\n\x03\x45TM\x10 \x12\x07\n\x03MSS\x10@\x12\n\n\x05POM_2\x10\x80\x01**\n\rConstellation\x12\x19\n\x15UNKNOWN_CONSTELLATION\x10\x00*J\n\x07Mission\x12\x13\n\x0fUNKNOWN_MISSION\x10\x00\x12\x0b\n\x07LANDSAT\x10\x02\x12\x08\n\x04NAIP\x10\x04\x12\x08\n\x04PNOA\x10\x08\x12\t\n\x05SWIFT\x10\x10\x42Y\n\x13\x63om.epl.protobuf.v1B\tStacProtoP\x01Z.github.com/geo-grpc/api/golang/epl/protobuf/v1\xa2\x02\x04STPBb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,epl_dot_protobuf_dot_v1_dot_geometry__pb2.DESCRIPTOR,epl_dot_protobuf_dot_v1_dot_query__pb2.DESCRIPTOR,])

_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='epl.protobuf.v1.AssetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ASSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEOTIFF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LERC', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MRF', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MRF_IDX', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MRF_XML', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CO_GEOTIFF', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THUMBNAIL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIFF', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG_2000', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XML', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TXT', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVERVIEW', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBP', index=18, number=18,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6215,
  serialized_end=6449,
)
_sym_db.RegisterEnumDescriptor(_ASSETTYPE)

AssetType = enum_type_wrapper.EnumTypeWrapper(_ASSETTYPE)
_CLOUDPLATFORM = _descriptor.EnumDescriptor(
  name='CloudPlatform',
  full_name='epl.protobuf.v1.CloudPlatform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CLOUD_PLATFORM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AWS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AZURE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IBM', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6451,
  serialized_end=6532,
)
_sym_db.RegisterEnumDescriptor(_CLOUDPLATFORM)

CloudPlatform = enum_type_wrapper.EnumTypeWrapper(_CLOUDPLATFORM)
_PLATFORM = _descriptor.EnumDescriptor(
  name='Platform',
  full_name='epl.protobuf.v1.Platform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PLATFORM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_1', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_2', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_3', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_123', index=4, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_4', index=5, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_5', index=6, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_45', index=7, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_7', index=8, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_8', index=9, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIFT_2', index=10, number=256,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6535,
  serialized_end=6720,
)
_sym_db.RegisterEnumDescriptor(_PLATFORM)

Platform = enum_type_wrapper.EnumTypeWrapper(_PLATFORM)
_INSTRUMENT = _descriptor.EnumDescriptor(
  name='Instrument',
  full_name='epl.protobuf.v1.Instrument',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_INSTRUMENT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLI', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIRS', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLI_TIRS', index=3, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POM_1', index=4, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TM', index=5, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ETM', index=6, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSS', index=7, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POM_2', index=8, number=128,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6722,
  serialized_end=6840,
)
_sym_db.RegisterEnumDescriptor(_INSTRUMENT)

Instrument = enum_type_wrapper.EnumTypeWrapper(_INSTRUMENT)
_CONSTELLATION = _descriptor.EnumDescriptor(
  name='Constellation',
  full_name='epl.protobuf.v1.Constellation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CONSTELLATION', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6842,
  serialized_end=6884,
)
_sym_db.RegisterEnumDescriptor(_CONSTELLATION)

Constellation = enum_type_wrapper.EnumTypeWrapper(_CONSTELLATION)
_MISSION = _descriptor.EnumDescriptor(
  name='Mission',
  full_name='epl.protobuf.v1.Mission',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_MISSION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAIP', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNOA', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIFT', index=4, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6886,
  serialized_end=6960,
)
_sym_db.RegisterEnumDescriptor(_MISSION)

Mission = enum_type_wrapper.EnumTypeWrapper(_MISSION)
UNKNOWN_ASSET = 0
JPEG = 1
GEOTIFF = 2
LERC = 3
MRF = 4
MRF_IDX = 5
MRF_XML = 6
CO_GEOTIFF = 7
RAW = 8
THUMBNAIL = 9
TIFF = 10
JPEG_2000 = 11
XML = 12
TXT = 13
PNG = 14
OVERVIEW = 15
JSON = 16
HTML = 17
WEBP = 18
UNKNOWN_CLOUD_PLATFORM = 0
AWS = 1
GCP = 2
AZURE = 3
IBM = 4
UNKNOWN_PLATFORM = 0
LANDSAT_1 = 2
LANDSAT_2 = 4
LANDSAT_3 = 8
LANDSAT_123 = 14
LANDSAT_4 = 16
LANDSAT_5 = 32
LANDSAT_45 = 48
LANDSAT_7 = 64
LANDSAT_8 = 128
SWIFT_2 = 256
UNKNOWN_INSTRUMENT = 0
OLI = 2
TIRS = 4
OLI_TIRS = 6
POM_1 = 8
TM = 16
ETM = 32
MSS = 64
POM_2 = 128
UNKNOWN_CONSTELLATION = 0
UNKNOWN_MISSION = 0
LANDSAT = 2
NAIP = 4
PNOA = 8
SWIFT = 16


_SAT_ORBITSTATE = _descriptor.EnumDescriptor(
  name='OrbitState',
  full_name='epl.protobuf.v1.Sat.OrbitState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UKNOWN_ORBIT_STATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASCENDING_ORBIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCENDING_ORBIT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEOSTATIONARY_ORBIT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4083,
  serialized_end=4187,
)
_sym_db.RegisterEnumDescriptor(_SAT_ORBITSTATE)

_EO_BAND = _descriptor.EnumDescriptor(
  name='Band',
  full_name='epl.protobuf.v1.Eo.Band',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BAND', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COASTAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RED', index=4, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RGB', index=5, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NIR', index=6, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NIR_2', index=7, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RGBIR', index=8, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIR_1', index=9, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIR_2', index=10, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAN', index=11, number=256,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CIRRUS', index=12, number=512,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LWIR_1', index=13, number=1024,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LWIR_2', index=14, number=2048,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4380,
  serialized_end=4561,
)
_sym_db.RegisterEnumDescriptor(_EO_BAND)

_SAR_PLATFORM = _descriptor.EnumDescriptor(
  name='Platform',
  full_name='epl.protobuf.v1.Sar.Platform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PLATFORM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENVISAT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENTINEL_1A', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5207,
  serialized_end=5269,
)
_sym_db.RegisterEnumDescriptor(_SAR_PLATFORM)

_SAR_INSTRUMENT = _descriptor.EnumDescriptor(
  name='Instrument',
  full_name='epl.protobuf.v1.Sar.Instrument',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_INSTRUMENT', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5271,
  serialized_end=5307,
)
_sym_db.RegisterEnumDescriptor(_SAR_INSTRUMENT)

_LANDSAT_COLLECTIONCATEGORY = _descriptor.EnumDescriptor(
  name='CollectionCategory',
  full_name='epl.protobuf.v1.Landsat.CollectionCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_COLLECTION_CATEGORY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='A1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='A2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T1', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T2', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RT', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5569,
  serialized_end=5662,
)
_sym_db.RegisterEnumDescriptor(_LANDSAT_COLLECTIONCATEGORY)

_LANDSAT_WRSTYPE = _descriptor.EnumDescriptor(
  name='WRSType',
  full_name='epl.protobuf.v1.Landsat.WRSType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UKNOWN_WRS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRS1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRS2', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5664,
  serialized_end=5709,
)
_sym_db.RegisterEnumDescriptor(_LANDSAT_WRSTYPE)

_LANDSAT_PROCESSINGLEVEL = _descriptor.EnumDescriptor(
  name='ProcessingLevel',
  full_name='epl.protobuf.v1.Landsat.ProcessingLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PROCESSING_LEVEL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L1G', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L1TP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L1T', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L1GT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L1GS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5711,
  serialized_end=5806,
)
_sym_db.RegisterEnumDescriptor(_LANDSAT_PROCESSINGLEVEL)


_COLLECTION_SUMMARIESENTRY = _descriptor.Descriptor(
  name='SummariesEntry',
  full_name='epl.protobuf.v1.Collection.SummariesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='epl.protobuf.v1.Collection.SummariesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.Collection.SummariesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=542,
)

_COLLECTION = _descriptor.Descriptor(
  name='Collection',
  full_name='epl.protobuf.v1.Collection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stac_version', full_name='epl.protobuf.v1.Collection.stac_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='epl.protobuf.v1.Collection.id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='epl.protobuf.v1.Collection.title', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='epl.protobuf.v1.Collection.description', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keywords', full_name='epl.protobuf.v1.Collection.keywords', index=4,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='license', full_name='epl.protobuf.v1.Collection.license', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='providers', full_name='epl.protobuf.v1.Collection.providers', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extent', full_name='epl.protobuf.v1.Collection.extent', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summaries', full_name='epl.protobuf.v1.Collection.summaries', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COLLECTION_SUMMARIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=554,
)


_COLLECTIONREQUEST = _descriptor.Descriptor(
  name='CollectionRequest',
  full_name='epl.protobuf.v1.CollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='epl.protobuf.v1.CollectionRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='epl.protobuf.v1.CollectionRequest.bbox', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intersects', full_name='epl.protobuf.v1.CollectionRequest.intersects', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spatial', full_name='epl.protobuf.v1.CollectionRequest.spatial',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=557,
  serialized_end=699,
)


_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='epl.protobuf.v1.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=701,
  serialized_end=708,
)


_EXTENT = _descriptor.Descriptor(
  name='Extent',
  full_name='epl.protobuf.v1.Extent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spatial', full_name='epl.protobuf.v1.Extent.spatial', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temporal', full_name='epl.protobuf.v1.Extent.temporal', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=811,
)


_INTERVAL = _descriptor.Descriptor(
  name='Interval',
  full_name='epl.protobuf.v1.Interval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.v1.Interval.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.v1.Interval.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=813,
  serialized_end=907,
)


_PROVIDER = _descriptor.Descriptor(
  name='Provider',
  full_name='epl.protobuf.v1.Provider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='epl.protobuf.v1.Provider.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='epl.protobuf.v1.Provider.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roles', full_name='epl.protobuf.v1.Provider.roles', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='epl.protobuf.v1.Provider.url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=982,
)


_STACITEM_ASSETSENTRY = _descriptor.Descriptor(
  name='AssetsEntry',
  full_name='epl.protobuf.v1.StacItem.AssetsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='epl.protobuf.v1.StacItem.AssetsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.StacItem.AssetsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2240,
  serialized_end=2309,
)

_STACITEM = _descriptor.Descriptor(
  name='StacItem',
  full_name='epl.protobuf.v1.StacItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='epl.protobuf.v1.StacItem.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='epl.protobuf.v1.StacItem.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='epl.protobuf.v1.StacItem.collection', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='epl.protobuf.v1.StacItem.properties', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assets', full_name='epl.protobuf.v1.StacItem.assets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='epl.protobuf.v1.StacItem.geometry', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='epl.protobuf.v1.StacItem.bbox', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='epl.protobuf.v1.StacItem.datetime', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_datetime', full_name='epl.protobuf.v1.StacItem.start_datetime', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observed', full_name='epl.protobuf.v1.StacItem.observed', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_observation', full_name='epl.protobuf.v1.StacItem.start_observation', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_datetime', full_name='epl.protobuf.v1.StacItem.end_datetime', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_observation', full_name='epl.protobuf.v1.StacItem.end_observation', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created', full_name='epl.protobuf.v1.StacItem.created', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated', full_name='epl.protobuf.v1.StacItem.updated', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proj', full_name='epl.protobuf.v1.StacItem.proj', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_enum', full_name='epl.protobuf.v1.StacItem.platform_enum', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform', full_name='epl.protobuf.v1.StacItem.platform', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_enum', full_name='epl.protobuf.v1.StacItem.instrument_enum', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument', full_name='epl.protobuf.v1.StacItem.instrument', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constellation_enum', full_name='epl.protobuf.v1.StacItem.constellation_enum', index=20,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constellation', full_name='epl.protobuf.v1.StacItem.constellation', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mission_enum', full_name='epl.protobuf.v1.StacItem.mission_enum', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mission', full_name='epl.protobuf.v1.StacItem.mission', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gsd', full_name='epl.protobuf.v1.StacItem.gsd', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stac_version', full_name='epl.protobuf.v1.StacItem.stac_version', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stac_pb_version', full_name='epl.protobuf.v1.StacItem.stac_pb_version', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stac_extensions', full_name='epl.protobuf.v1.StacItem.stac_extensions', index=27,
      number=28, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eo', full_name='epl.protobuf.v1.StacItem.eo', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='epl.protobuf.v1.StacItem.view', index=29,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='landsat', full_name='epl.protobuf.v1.StacItem.landsat', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mosaic', full_name='epl.protobuf.v1.StacItem.mosaic', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STACITEM_ASSETSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='temporal_deprecated', full_name='epl.protobuf.v1.StacItem.temporal_deprecated',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='temporal', full_name='epl.protobuf.v1.StacItem.temporal',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=985,
  serialized_end=2344,
)


_STACREQUEST = _descriptor.Descriptor(
  name='StacRequest',
  full_name='epl.protobuf.v1.StacRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='epl.protobuf.v1.StacRequest.limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='epl.protobuf.v1.StacRequest.offset', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='epl.protobuf.v1.StacRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_complex', full_name='epl.protobuf.v1.StacRequest.id_complex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='epl.protobuf.v1.StacRequest.collection', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='epl.protobuf.v1.StacRequest.properties', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intersects', full_name='epl.protobuf.v1.StacRequest.intersects', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='epl.protobuf.v1.StacRequest.bbox', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry_request', full_name='epl.protobuf.v1.StacRequest.geometry_request', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='epl.protobuf.v1.StacRequest.datetime', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observed', full_name='epl.protobuf.v1.StacRequest.observed', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created', full_name='epl.protobuf.v1.StacRequest.created', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated', full_name='epl.protobuf.v1.StacRequest.updated', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proj', full_name='epl.protobuf.v1.StacRequest.proj', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_enum', full_name='epl.protobuf.v1.StacRequest.platform_enum', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_enum', full_name='epl.protobuf.v1.StacRequest.instrument_enum', index=15,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constellation_enum', full_name='epl.protobuf.v1.StacRequest.constellation_enum', index=16,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mission_enum', full_name='epl.protobuf.v1.StacRequest.mission_enum', index=17,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gsd', full_name='epl.protobuf.v1.StacRequest.gsd', index=18,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eo', full_name='epl.protobuf.v1.StacRequest.eo', index=19,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='epl.protobuf.v1.StacRequest.view', index=20,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='landsat', full_name='epl.protobuf.v1.StacRequest.landsat', index=21,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mosaic', full_name='epl.protobuf.v1.StacRequest.mosaic', index=22,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identity', full_name='epl.protobuf.v1.StacRequest.identity',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='spatial', full_name='epl.protobuf.v1.StacRequest.spatial',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='temporal', full_name='epl.protobuf.v1.StacRequest.temporal',
      index=2, containing_type=None, fields=[]),
  ],
  serialized_start=2347,
  serialized_end=3435,
)


_VIEW = _descriptor.Descriptor(
  name='View',
  full_name='epl.protobuf.v1.View',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='off_nadir', full_name='epl.protobuf.v1.View.off_nadir', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incidence_angle', full_name='epl.protobuf.v1.View.incidence_angle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='epl.protobuf.v1.View.azimuth', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_azimuth', full_name='epl.protobuf.v1.View.sun_azimuth', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_elevation', full_name='epl.protobuf.v1.View.sun_elevation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3438,
  serialized_end=3694,
)


_VIEWREQUEST = _descriptor.Descriptor(
  name='ViewRequest',
  full_name='epl.protobuf.v1.ViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='off_nadir', full_name='epl.protobuf.v1.ViewRequest.off_nadir', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incidence_angle', full_name='epl.protobuf.v1.ViewRequest.incidence_angle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='epl.protobuf.v1.ViewRequest.azimuth', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_azimuth', full_name='epl.protobuf.v1.ViewRequest.sun_azimuth', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_elevation', full_name='epl.protobuf.v1.ViewRequest.sun_elevation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3697,
  serialized_end=3965,
)


_SAT = _descriptor.Descriptor(
  name='Sat',
  full_name='epl.protobuf.v1.Sat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relative_orbit', full_name='epl.protobuf.v1.Sat.relative_orbit', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orbit_state', full_name='epl.protobuf.v1.Sat.orbit_state', index=1,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SAT_ORBITSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3968,
  serialized_end=4187,
)


_SATREQUEST = _descriptor.Descriptor(
  name='SatRequest',
  full_name='epl.protobuf.v1.SatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relative_orbit', full_name='epl.protobuf.v1.SatRequest.relative_orbit', index=0,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orbit_state', full_name='epl.protobuf.v1.SatRequest.orbit_state', index=1,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4189,
  serialized_end=4279,
)


_EO = _descriptor.Descriptor(
  name='Eo',
  full_name='epl.protobuf.v1.Eo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_cover', full_name='epl.protobuf.v1.Eo.cloud_cover', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='epl.protobuf.v1.Eo.bands', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EO_BAND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4282,
  serialized_end=4561,
)


_EOREQUEST = _descriptor.Descriptor(
  name='EoRequest',
  full_name='epl.protobuf.v1.EoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_cover', full_name='epl.protobuf.v1.EoRequest.cloud_cover', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='epl.protobuf.v1.EoRequest.bands', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4563,
  serialized_end=4666,
)


_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='epl.protobuf.v1.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='href', full_name='epl.protobuf.v1.Asset.href', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='epl.protobuf.v1.Asset.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eo_bands', full_name='epl.protobuf.v1.Asset.eo_bands', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_type', full_name='epl.protobuf.v1.Asset.asset_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_platform', full_name='epl.protobuf.v1.Asset.cloud_platform', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket_manager', full_name='epl.protobuf.v1.Asset.bucket_manager', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket_region', full_name='epl.protobuf.v1.Asset.bucket_region', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='epl.protobuf.v1.Asset.bucket', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_path', full_name='epl.protobuf.v1.Asset.object_path', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requester_pays', full_name='epl.protobuf.v1.Asset.requester_pays', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4669,
  serialized_end=4960,
)


_DATETIMERANGE = _descriptor.Descriptor(
  name='DatetimeRange',
  full_name='epl.protobuf.v1.DatetimeRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.v1.DatetimeRange.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.v1.DatetimeRange.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4962,
  serialized_end=5061,
)


_STACDBRESPONSE = _descriptor.Descriptor(
  name='StacDbResponse',
  full_name='epl.protobuf.v1.StacDbResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='epl.protobuf.v1.StacDbResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='epl.protobuf.v1.StacDbResponse.status_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_id', full_name='epl.protobuf.v1.StacDbResponse.data_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='epl.protobuf.v1.StacDbResponse.count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5063,
  serialized_end=5148,
)


_SAR = _descriptor.Descriptor(
  name='Sar',
  full_name='epl.protobuf.v1.Sar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='platform', full_name='epl.protobuf.v1.Sar.platform', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SAR_PLATFORM,
    _SAR_INSTRUMENT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5151,
  serialized_end=5307,
)


_LANDSAT = _descriptor.Descriptor(
  name='Landsat',
  full_name='epl.protobuf.v1.Landsat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scene_id', full_name='epl.protobuf.v1.Landsat.scene_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='epl.protobuf.v1.Landsat.product_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processing_level', full_name='epl.protobuf.v1.Landsat.processing_level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wrs_path', full_name='epl.protobuf.v1.Landsat.wrs_path', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wrs_row', full_name='epl.protobuf.v1.Landsat.wrs_row', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_cover_land', full_name='epl.protobuf.v1.Landsat.cloud_cover_land', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wrs_type', full_name='epl.protobuf.v1.Landsat.wrs_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANDSAT_COLLECTIONCATEGORY,
    _LANDSAT_WRSTYPE,
    _LANDSAT_PROCESSINGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5310,
  serialized_end=5806,
)


_LANDSATREQUEST = _descriptor.Descriptor(
  name='LandsatRequest',
  full_name='epl.protobuf.v1.LandsatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scene_id', full_name='epl.protobuf.v1.LandsatRequest.scene_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='epl.protobuf.v1.LandsatRequest.product_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processing_level', full_name='epl.protobuf.v1.LandsatRequest.processing_level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wrs_path', full_name='epl.protobuf.v1.LandsatRequest.wrs_path', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wrs_row', full_name='epl.protobuf.v1.LandsatRequest.wrs_row', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_cover_land', full_name='epl.protobuf.v1.LandsatRequest.cloud_cover_land', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5809,
  serialized_end=6022,
)


_MOSAIC = _descriptor.Descriptor(
  name='Mosaic',
  full_name='epl.protobuf.v1.Mosaic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='epl.protobuf.v1.Mosaic.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quad_key', full_name='epl.protobuf.v1.Mosaic.quad_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zooms', full_name='epl.protobuf.v1.Mosaic.zooms', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observation_range', full_name='epl.protobuf.v1.Mosaic.observation_range', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenance_ids', full_name='epl.protobuf.v1.Mosaic.provenance_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6025,
  serialized_end=6163,
)


_MOSAICREQUEST = _descriptor.Descriptor(
  name='MosaicRequest',
  full_name='epl.protobuf.v1.MosaicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='epl.protobuf.v1.MosaicRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quad_key', full_name='epl.protobuf.v1.MosaicRequest.quad_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6165,
  serialized_end=6212,
)

_COLLECTION_SUMMARIESENTRY.fields_by_name['value'].message_type = _STATS
_COLLECTION_SUMMARIESENTRY.containing_type = _COLLECTION
_COLLECTION.fields_by_name['providers'].message_type = _PROVIDER
_COLLECTION.fields_by_name['extent'].message_type = _EXTENT
_COLLECTION.fields_by_name['summaries'].message_type = _COLLECTION_SUMMARIESENTRY
_COLLECTIONREQUEST.fields_by_name['bbox'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._ENVELOPEDATA
_COLLECTIONREQUEST.fields_by_name['intersects'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._GEOMETRYDATA
_COLLECTIONREQUEST.oneofs_by_name['spatial'].fields.append(
  _COLLECTIONREQUEST.fields_by_name['bbox'])
_COLLECTIONREQUEST.fields_by_name['bbox'].containing_oneof = _COLLECTIONREQUEST.oneofs_by_name['spatial']
_COLLECTIONREQUEST.oneofs_by_name['spatial'].fields.append(
  _COLLECTIONREQUEST.fields_by_name['intersects'])
_COLLECTIONREQUEST.fields_by_name['intersects'].containing_oneof = _COLLECTIONREQUEST.oneofs_by_name['spatial']
_EXTENT.fields_by_name['spatial'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._ENVELOPEDATA
_EXTENT.fields_by_name['temporal'].message_type = _INTERVAL
_INTERVAL.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INTERVAL.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM_ASSETSENTRY.fields_by_name['value'].message_type = _ASSET
_STACITEM_ASSETSENTRY.containing_type = _STACITEM
_STACITEM.fields_by_name['properties'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STACITEM.fields_by_name['assets'].message_type = _STACITEM_ASSETSENTRY
_STACITEM.fields_by_name['geometry'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._GEOMETRYDATA
_STACITEM.fields_by_name['bbox'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._ENVELOPEDATA
_STACITEM.fields_by_name['datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['start_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['observed'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['start_observation'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['end_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['end_observation'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACITEM.fields_by_name['proj'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._PROJECTIONDATA
_STACITEM.fields_by_name['platform_enum'].enum_type = _PLATFORM
_STACITEM.fields_by_name['instrument_enum'].enum_type = _INSTRUMENT
_STACITEM.fields_by_name['constellation_enum'].enum_type = _CONSTELLATION
_STACITEM.fields_by_name['mission_enum'].enum_type = _MISSION
_STACITEM.fields_by_name['gsd'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_STACITEM.fields_by_name['eo'].message_type = _EO
_STACITEM.fields_by_name['view'].message_type = _VIEW
_STACITEM.fields_by_name['landsat'].message_type = _LANDSAT
_STACITEM.fields_by_name['mosaic'].message_type = _MOSAIC
_STACITEM.oneofs_by_name['temporal_deprecated'].fields.append(
  _STACITEM.fields_by_name['datetime'])
_STACITEM.fields_by_name['datetime'].containing_oneof = _STACITEM.oneofs_by_name['temporal_deprecated']
_STACITEM.oneofs_by_name['temporal_deprecated'].fields.append(
  _STACITEM.fields_by_name['start_datetime'])
_STACITEM.fields_by_name['start_datetime'].containing_oneof = _STACITEM.oneofs_by_name['temporal_deprecated']
_STACITEM.oneofs_by_name['temporal'].fields.append(
  _STACITEM.fields_by_name['observed'])
_STACITEM.fields_by_name['observed'].containing_oneof = _STACITEM.oneofs_by_name['temporal']
_STACITEM.oneofs_by_name['temporal'].fields.append(
  _STACITEM.fields_by_name['start_observation'])
_STACITEM.fields_by_name['start_observation'].containing_oneof = _STACITEM.oneofs_by_name['temporal']
_STACREQUEST.fields_by_name['id_complex'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._STRINGFILTER
_STACREQUEST.fields_by_name['properties'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STACREQUEST.fields_by_name['intersects'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._GEOMETRYDATA
_STACREQUEST.fields_by_name['bbox'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._ENVELOPEDATA
_STACREQUEST.fields_by_name['geometry_request'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._GEOMETRYREQUEST
_STACREQUEST.fields_by_name['datetime'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._TIMESTAMPFILTER
_STACREQUEST.fields_by_name['observed'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._TIMESTAMPFILTER
_STACREQUEST.fields_by_name['created'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._TIMESTAMPFILTER
_STACREQUEST.fields_by_name['updated'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._TIMESTAMPFILTER
_STACREQUEST.fields_by_name['proj'].message_type = epl_dot_protobuf_dot_v1_dot_geometry__pb2._PROJECTIONDATA
_STACREQUEST.fields_by_name['platform_enum'].enum_type = _PLATFORM
_STACREQUEST.fields_by_name['instrument_enum'].enum_type = _INSTRUMENT
_STACREQUEST.fields_by_name['constellation_enum'].enum_type = _CONSTELLATION
_STACREQUEST.fields_by_name['mission_enum'].enum_type = _MISSION
_STACREQUEST.fields_by_name['gsd'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_STACREQUEST.fields_by_name['eo'].message_type = _EOREQUEST
_STACREQUEST.fields_by_name['view'].message_type = _VIEWREQUEST
_STACREQUEST.fields_by_name['landsat'].message_type = _LANDSATREQUEST
_STACREQUEST.fields_by_name['mosaic'].message_type = _MOSAICREQUEST
_STACREQUEST.oneofs_by_name['identity'].fields.append(
  _STACREQUEST.fields_by_name['id'])
_STACREQUEST.fields_by_name['id'].containing_oneof = _STACREQUEST.oneofs_by_name['identity']
_STACREQUEST.oneofs_by_name['identity'].fields.append(
  _STACREQUEST.fields_by_name['id_complex'])
_STACREQUEST.fields_by_name['id_complex'].containing_oneof = _STACREQUEST.oneofs_by_name['identity']
_STACREQUEST.oneofs_by_name['spatial'].fields.append(
  _STACREQUEST.fields_by_name['intersects'])
_STACREQUEST.fields_by_name['intersects'].containing_oneof = _STACREQUEST.oneofs_by_name['spatial']
_STACREQUEST.oneofs_by_name['spatial'].fields.append(
  _STACREQUEST.fields_by_name['bbox'])
_STACREQUEST.fields_by_name['bbox'].containing_oneof = _STACREQUEST.oneofs_by_name['spatial']
_STACREQUEST.oneofs_by_name['spatial'].fields.append(
  _STACREQUEST.fields_by_name['geometry_request'])
_STACREQUEST.fields_by_name['geometry_request'].containing_oneof = _STACREQUEST.oneofs_by_name['spatial']
_STACREQUEST.oneofs_by_name['temporal'].fields.append(
  _STACREQUEST.fields_by_name['datetime'])
_STACREQUEST.fields_by_name['datetime'].containing_oneof = _STACREQUEST.oneofs_by_name['temporal']
_STACREQUEST.oneofs_by_name['temporal'].fields.append(
  _STACREQUEST.fields_by_name['observed'])
_STACREQUEST.fields_by_name['observed'].containing_oneof = _STACREQUEST.oneofs_by_name['temporal']
_VIEW.fields_by_name['off_nadir'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VIEW.fields_by_name['incidence_angle'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VIEW.fields_by_name['azimuth'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VIEW.fields_by_name['sun_azimuth'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VIEW.fields_by_name['sun_elevation'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VIEWREQUEST.fields_by_name['off_nadir'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_VIEWREQUEST.fields_by_name['incidence_angle'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_VIEWREQUEST.fields_by_name['azimuth'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_VIEWREQUEST.fields_by_name['sun_azimuth'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_VIEWREQUEST.fields_by_name['sun_elevation'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_SAT.fields_by_name['relative_orbit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_SAT.fields_by_name['orbit_state'].enum_type = _SAT_ORBITSTATE
_SAT_ORBITSTATE.containing_type = _SAT
_SATREQUEST.fields_by_name['orbit_state'].enum_type = _SAT_ORBITSTATE
_EO.fields_by_name['cloud_cover'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['bands'].enum_type = _EO_BAND
_EO_BAND.containing_type = _EO
_EOREQUEST.fields_by_name['cloud_cover'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_EOREQUEST.fields_by_name['bands'].enum_type = _EO_BAND
_ASSET.fields_by_name['eo_bands'].enum_type = _EO_BAND
_ASSET.fields_by_name['asset_type'].enum_type = _ASSETTYPE
_ASSET.fields_by_name['cloud_platform'].enum_type = _CLOUDPLATFORM
_DATETIMERANGE.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATETIMERANGE.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SAR.fields_by_name['platform'].enum_type = _SAR_PLATFORM
_SAR_PLATFORM.containing_type = _SAR
_SAR_INSTRUMENT.containing_type = _SAR
_LANDSAT.fields_by_name['processing_level'].enum_type = _LANDSAT_PROCESSINGLEVEL
_LANDSAT.fields_by_name['cloud_cover_land'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_LANDSAT.fields_by_name['wrs_type'].enum_type = _LANDSAT_WRSTYPE
_LANDSAT_COLLECTIONCATEGORY.containing_type = _LANDSAT
_LANDSAT_WRSTYPE.containing_type = _LANDSAT
_LANDSAT_PROCESSINGLEVEL.containing_type = _LANDSAT
_LANDSATREQUEST.fields_by_name['processing_level'].enum_type = _LANDSAT_PROCESSINGLEVEL
_LANDSATREQUEST.fields_by_name['cloud_cover_land'].message_type = epl_dot_protobuf_dot_v1_dot_query__pb2._FLOATFILTER
_MOSAIC.fields_by_name['observation_range'].message_type = _DATETIMERANGE
DESCRIPTOR.message_types_by_name['Collection'] = _COLLECTION
DESCRIPTOR.message_types_by_name['CollectionRequest'] = _COLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['Stats'] = _STATS
DESCRIPTOR.message_types_by_name['Extent'] = _EXTENT
DESCRIPTOR.message_types_by_name['Interval'] = _INTERVAL
DESCRIPTOR.message_types_by_name['Provider'] = _PROVIDER
DESCRIPTOR.message_types_by_name['StacItem'] = _STACITEM
DESCRIPTOR.message_types_by_name['StacRequest'] = _STACREQUEST
DESCRIPTOR.message_types_by_name['View'] = _VIEW
DESCRIPTOR.message_types_by_name['ViewRequest'] = _VIEWREQUEST
DESCRIPTOR.message_types_by_name['Sat'] = _SAT
DESCRIPTOR.message_types_by_name['SatRequest'] = _SATREQUEST
DESCRIPTOR.message_types_by_name['Eo'] = _EO
DESCRIPTOR.message_types_by_name['EoRequest'] = _EOREQUEST
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['DatetimeRange'] = _DATETIMERANGE
DESCRIPTOR.message_types_by_name['StacDbResponse'] = _STACDBRESPONSE
DESCRIPTOR.message_types_by_name['Sar'] = _SAR
DESCRIPTOR.message_types_by_name['Landsat'] = _LANDSAT
DESCRIPTOR.message_types_by_name['LandsatRequest'] = _LANDSATREQUEST
DESCRIPTOR.message_types_by_name['Mosaic'] = _MOSAIC
DESCRIPTOR.message_types_by_name['MosaicRequest'] = _MOSAICREQUEST
DESCRIPTOR.enum_types_by_name['AssetType'] = _ASSETTYPE
DESCRIPTOR.enum_types_by_name['CloudPlatform'] = _CLOUDPLATFORM
DESCRIPTOR.enum_types_by_name['Platform'] = _PLATFORM
DESCRIPTOR.enum_types_by_name['Instrument'] = _INSTRUMENT
DESCRIPTOR.enum_types_by_name['Constellation'] = _CONSTELLATION
DESCRIPTOR.enum_types_by_name['Mission'] = _MISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Collection = _reflection.GeneratedProtocolMessageType('Collection', (_message.Message,), {

  'SummariesEntry' : _reflection.GeneratedProtocolMessageType('SummariesEntry', (_message.Message,), {
    'DESCRIPTOR' : _COLLECTION_SUMMARIESENTRY,
    '__module__' : 'epl.protobuf.v1.stac_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Collection.SummariesEntry)
    })
  ,
  'DESCRIPTOR' : _COLLECTION,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Collection)
  })
_sym_db.RegisterMessage(Collection)
_sym_db.RegisterMessage(Collection.SummariesEntry)

CollectionRequest = _reflection.GeneratedProtocolMessageType('CollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.CollectionRequest)
  })
_sym_db.RegisterMessage(CollectionRequest)

Stats = _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {
  'DESCRIPTOR' : _STATS,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Stats)
  })
_sym_db.RegisterMessage(Stats)

Extent = _reflection.GeneratedProtocolMessageType('Extent', (_message.Message,), {
  'DESCRIPTOR' : _EXTENT,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Extent)
  })
_sym_db.RegisterMessage(Extent)

Interval = _reflection.GeneratedProtocolMessageType('Interval', (_message.Message,), {
  'DESCRIPTOR' : _INTERVAL,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Interval)
  })
_sym_db.RegisterMessage(Interval)

Provider = _reflection.GeneratedProtocolMessageType('Provider', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDER,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Provider)
  })
_sym_db.RegisterMessage(Provider)

StacItem = _reflection.GeneratedProtocolMessageType('StacItem', (_message.Message,), {

  'AssetsEntry' : _reflection.GeneratedProtocolMessageType('AssetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STACITEM_ASSETSENTRY,
    '__module__' : 'epl.protobuf.v1.stac_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.StacItem.AssetsEntry)
    })
  ,
  'DESCRIPTOR' : _STACITEM,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.StacItem)
  })
_sym_db.RegisterMessage(StacItem)
_sym_db.RegisterMessage(StacItem.AssetsEntry)

StacRequest = _reflection.GeneratedProtocolMessageType('StacRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.StacRequest)
  })
_sym_db.RegisterMessage(StacRequest)

View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
  'DESCRIPTOR' : _VIEW,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.View)
  })
_sym_db.RegisterMessage(View)

ViewRequest = _reflection.GeneratedProtocolMessageType('ViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _VIEWREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.ViewRequest)
  })
_sym_db.RegisterMessage(ViewRequest)

Sat = _reflection.GeneratedProtocolMessageType('Sat', (_message.Message,), {
  'DESCRIPTOR' : _SAT,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Sat)
  })
_sym_db.RegisterMessage(Sat)

SatRequest = _reflection.GeneratedProtocolMessageType('SatRequest', (_message.Message,), {
  'DESCRIPTOR' : _SATREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.SatRequest)
  })
_sym_db.RegisterMessage(SatRequest)

Eo = _reflection.GeneratedProtocolMessageType('Eo', (_message.Message,), {
  'DESCRIPTOR' : _EO,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Eo)
  })
_sym_db.RegisterMessage(Eo)

EoRequest = _reflection.GeneratedProtocolMessageType('EoRequest', (_message.Message,), {
  'DESCRIPTOR' : _EOREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.EoRequest)
  })
_sym_db.RegisterMessage(EoRequest)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Asset)
  })
_sym_db.RegisterMessage(Asset)

DatetimeRange = _reflection.GeneratedProtocolMessageType('DatetimeRange', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMERANGE,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.DatetimeRange)
  })
_sym_db.RegisterMessage(DatetimeRange)

StacDbResponse = _reflection.GeneratedProtocolMessageType('StacDbResponse', (_message.Message,), {
  'DESCRIPTOR' : _STACDBRESPONSE,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.StacDbResponse)
  })
_sym_db.RegisterMessage(StacDbResponse)

Sar = _reflection.GeneratedProtocolMessageType('Sar', (_message.Message,), {
  'DESCRIPTOR' : _SAR,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Sar)
  })
_sym_db.RegisterMessage(Sar)

Landsat = _reflection.GeneratedProtocolMessageType('Landsat', (_message.Message,), {
  'DESCRIPTOR' : _LANDSAT,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Landsat)
  })
_sym_db.RegisterMessage(Landsat)

LandsatRequest = _reflection.GeneratedProtocolMessageType('LandsatRequest', (_message.Message,), {
  'DESCRIPTOR' : _LANDSATREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.LandsatRequest)
  })
_sym_db.RegisterMessage(LandsatRequest)

Mosaic = _reflection.GeneratedProtocolMessageType('Mosaic', (_message.Message,), {
  'DESCRIPTOR' : _MOSAIC,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Mosaic)
  })
_sym_db.RegisterMessage(Mosaic)

MosaicRequest = _reflection.GeneratedProtocolMessageType('MosaicRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOSAICREQUEST,
  '__module__' : 'epl.protobuf.v1.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.MosaicRequest)
  })
_sym_db.RegisterMessage(MosaicRequest)


DESCRIPTOR._options = None
_COLLECTION_SUMMARIESENTRY._options = None
_STACITEM_ASSETSENTRY._options = None
# @@protoc_insertion_point(module_scope)
